@@ -15,12 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import Dict
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.redis.hooks.redis import RedisHook
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class RedisPublishOperator(BaseOperator):
@@ -28,34 +31,29 @@ class RedisPublishOperator(BaseOperator):
     Publish a message to Redis.
 
     :param channel: redis channel to which the message is published (templated)
-    :type channel: str
     :param message: the message to publish (templated)
-    :type message: str
     :param redis_conn_id: redis connection to use
-    :type redis_conn_id: str
     """
 
-    template_fields = ('channel', 'message')
+    template_fields: Sequence[str] = ("channel", "message")
 
-    @apply_defaults
-    def __init__(self, *, channel: str, message: str, redis_conn_id: str = 'redis_default', **kwargs) -> None:
+    def __init__(self, *, channel: str, message: str, redis_conn_id: str = "redis_default", **kwargs) -> None:
 
         super().__init__(**kwargs)
         self.redis_conn_id = redis_conn_id
         self.channel = channel
         self.message = message
 
-    def execute(self, context: Dict) -> None:
+    def execute(self, context: Context) -> None:
         """
         Publish the message to Redis channel
 
         :param context: the context object
-        :type context: dict
         """
         redis_hook = RedisHook(redis_conn_id=self.redis_conn_id)
 
-        self.log.info('Sending message %s to Redis on channel %s', self.message, self.channel)
+        self.log.info("Sending message %s to Redis on channel %s", self.message, self.channel)
 
         result = redis_hook.get_conn().publish(channel=self.channel, message=self.message)
 
-        self.log.info('Result of publishing %s', result)
+        self.log.info("Result of publishing %s", result)
